@@ -1,7 +1,7 @@
 """
     The Auction class represents an auction for a Board.
 """
-
+import json
 from typing import Dict, List, Union
 
 __all__ = ['Auction']
@@ -29,6 +29,9 @@ class Auction(object):
 
     def __init__(self, calls: Union[List[Call], None] = None, first_caller: Union[str, int] = ''):
         """Create an auction with the given calls and first_caller."""
+        self._initialise(calls, first_caller)
+
+    def _initialise(self, calls, first_caller):
         self._first_caller = first_caller
         if not calls:
             calls = []
@@ -135,3 +138,22 @@ class Auction(object):
             seat_index += 1
             seat_index %= 4
         return seat_calls
+
+    def to_json(self):
+        """Return a json representation of the class."""
+        context = {
+            'calls': [call.name for call in self.calls],
+            'first_caller': self.first_caller,
+        }
+        return json.dumps(context)
+
+    def from_json(self, json_str):
+        """Construct and return the class from json input."""
+        calls, first_caller = [], ''
+        context = json.loads(json_str)
+        if 'calls' in context:
+            calls = [Call(name) for name in context['calls']]
+        if 'first_caller' in context:
+            first_caller = context['first_caller']
+        self._initialise(calls, first_caller)
+        return self
\ No newline at end of file
