@@ -1,6 +1,7 @@
 """Constants used in many bridgeobjects modules."""
 
-__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES', 'DENOMINATION_NAMES',
+__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'VULNERABILITY',
+            'CALLS', 'CONTRACTS', 'SUIT_NAMES', 'DENOMINATION_NAMES',
             'RANKS', 'SUITS', 'BALANCED_SHAPES', 'SEMI_BALANCED_SHAPES',
             'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS',
             'CARD_NAMES', 'CARD_VALUES', 'DISPLAY_SUIT_ORDER']
@@ -26,6 +27,13 @@ ROLES = {'Opener': 0,
 #: valid vulnerable values
 VULNERABLE = ['None', 'NS', 'EW', 'Both', 'All']
 
+VULNERABILITY = [
+    'None', 'NS', 'EW', 'Both',
+    'NS', 'EW', 'Both', 'None',
+    'EW', 'Both', 'None', 'NS',
+    'Both', 'None', 'NS', 'EW',
+]
+
 #: valid call names (P=Pass, D=Double, R=Redouble, A=All pass)
 CALLS = ['1C', '1D', '1H', '1S', '1NT',
          '2C', '2D', '2H', '2S', '2NT',
